==> knative-model-4.9.0-sources.jar: io/fabric8/knative/duck/v1/DestinationFluentImpl.java <==
package io.fabric8.knative.duck.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.v1.URL;
import io.fabric8.knative.v1.URLBuilder;
import io.fabric8.knative.v1.URLFluentImpl;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class DestinationFluentImpl<A extends DestinationFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements DestinationFluent<A>{

    private KReferenceBuilder ref;
    private URLBuilder uri;

    public DestinationFluentImpl(){
    }
    public DestinationFluentImpl(Destination instance){
            this.withRef(instance.getRef()); 
            this.withUri(instance.getUri()); 
    }

    
/**
 * This method has been deprecated, please use method buildRef instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public KReference getRef(){
            return this.ref!=null?this.ref.build():null;
    }

    public KReference buildRef(){
            return this.ref!=null?this.ref.build():null;
    }

    public A withRef(KReference ref){
            _visitables.get("ref").remove(this.ref);
            if (ref!=null){ this.ref= new KReferenceBuilder(ref); _visitables.get("ref").add(this.ref);} return (A) this;
    }

    public Boolean hasRef(){
            return this.ref != null;
    }

    public A withNewRef(String apiVersion,String kind,String name,String namespace){
            return (A)withRef(new KReference(apiVersion, kind, name, namespace));
    }

    public DestinationFluent.RefNested<A> withNewRef(){
            return new RefNestedImpl();
    }

    public DestinationFluent.RefNested<A> withNewRefLike(KReference item){
            return new RefNestedImpl(item);
    }

    public DestinationFluent.RefNested<A> editRef(){
            return withNewRefLike(getRef());
    }

    public DestinationFluent.RefNested<A> editOrNewRef(){
            return withNewRefLike(getRef() != null ? getRef(): new KReferenceBuilder().build());
    }

    public DestinationFluent.RefNested<A> editOrNewRefLike(KReference item){
            return withNewRefLike(getRef() != null ? getRef(): item);
    }

    
/**
 * This method has been deprecated, please use method buildUri instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public URL getUri(){
            return this.uri!=null?this.uri.build():null;
    }

    public URL buildUri(){
            return this.uri!=null?this.uri.build():null;
    }

    public A withUri(URL uri){
            _visitables.get("uri").remove(this.uri);
            if (uri!=null){ this.uri= new URLBuilder(uri); _visitables.get("uri").add(this.uri);} return (A) this;
    }

    public Boolean hasUri(){
            return this.uri != null;
    }

    public DestinationFluent.UriNested<A> withNewUri(){
            return new UriNestedImpl();
    }

    public DestinationFluent.UriNested<A> withNewUriLike(URL item){
            return new UriNestedImpl(item);
    }

    public DestinationFluent.UriNested<A> editUri(){
            return withNewUriLike(getUri());
    }

    public DestinationFluent.UriNested<A> editOrNewUri(){
            return withNewUriLike(getUri() != null ? getUri(): new URLBuilder().build());
    }

    public DestinationFluent.UriNested<A> editOrNewUriLike(URL item){
            return withNewUriLike(getUri() != null ? getUri(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            DestinationFluentImpl that = (DestinationFluentImpl) o;
            if (ref != null ? !ref.equals(that.ref) :that.ref != null) return false;
            if (uri != null ? !uri.equals(that.uri) :that.uri != null) return false;
            return true;
    }


    public class RefNestedImpl<N> extends KReferenceFluentImpl<DestinationFluent.RefNested<N>> implements DestinationFluent.RefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final KReferenceBuilder builder;
    
            RefNestedImpl(KReference item){
                    this.builder = new KReferenceBuilder(this, item);
            }
            RefNestedImpl(){
                    this.builder = new KReferenceBuilder(this);
            }
    
    public N and(){
            return (N) DestinationFluentImpl.this.withRef(builder.build());
    }
    public N endRef(){
            return and();
    }

}
    public class UriNestedImpl<N> extends URLFluentImpl<DestinationFluent.UriNested<N>> implements DestinationFluent.UriNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final URLBuilder builder;
    
            UriNestedImpl(URL item){
                    this.builder = new URLBuilder(this, item);
            }
            UriNestedImpl(){
                    this.builder = new URLBuilder(this);
            }
    
    public N and(){
            return (N) DestinationFluentImpl.this.withUri(builder.build());
    }
    public N endUri(){
            return and();
    }

}


}

==> knative-model-4.9.2-sources.jar: io/fabric8/knative/duck/v1/DestinationFluentImpl.java <==
package io.fabric8.knative.duck.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class DestinationFluentImpl<A extends DestinationFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements DestinationFluent<A>{

    private KReferenceBuilder ref;
    private String uri;

    public DestinationFluentImpl(){
    }
    public DestinationFluentImpl(Destination instance){
            this.withRef(instance.getRef()); 
            this.withUri(instance.getUri()); 
    }

    
/**
 * This method has been deprecated, please use method buildRef instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public KReference getRef(){
            return this.ref!=null?this.ref.build():null;
    }

    public KReference buildRef(){
            return this.ref!=null?this.ref.build():null;
    }

    public A withRef(KReference ref){
            _visitables.get("ref").remove(this.ref);
            if (ref!=null){ this.ref= new KReferenceBuilder(ref); _visitables.get("ref").add(this.ref);} return (A) this;
    }

    public Boolean hasRef(){
            return this.ref != null;
    }

    public A withNewRef(String apiVersion,String kind,String name,String namespace){
            return (A)withRef(new KReference(apiVersion, kind, name, namespace));
    }

    public DestinationFluent.RefNested<A> withNewRef(){
            return new RefNestedImpl();
    }

    public DestinationFluent.RefNested<A> withNewRefLike(KReference item){
            return new RefNestedImpl(item);
    }

    public DestinationFluent.RefNested<A> editRef(){
            return withNewRefLike(getRef());
    }

    public DestinationFluent.RefNested<A> editOrNewRef(){
            return withNewRefLike(getRef() != null ? getRef(): new KReferenceBuilder().build());
    }

    public DestinationFluent.RefNested<A> editOrNewRefLike(KReference item){
            return withNewRefLike(getRef() != null ? getRef(): item);
    }

    public String getUri(){
            return this.uri;
    }

    public A withUri(String uri){
            this.uri=uri; return (A) this;
    }

    public Boolean hasUri(){
            return this.uri != null;
    }

    public A withNewUri(String arg1){
            return (A)withUri(new String(arg1));
    }

    public A withNewUri(StringBuilder arg1){
            return (A)withUri(new String(arg1));
    }

    public A withNewUri(StringBuffer arg1){
            return (A)withUri(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            DestinationFluentImpl that = (DestinationFluentImpl) o;
            if (ref != null ? !ref.equals(that.ref) :that.ref != null) return false;
            if (uri != null ? !uri.equals(that.uri) :that.uri != null) return false;
            return true;
    }


    public class RefNestedImpl<N> extends KReferenceFluentImpl<DestinationFluent.RefNested<N>> implements DestinationFluent.RefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final KReferenceBuilder builder;
    
            RefNestedImpl(KReference item){
                    this.builder = new KReferenceBuilder(this, item);
            }
            RefNestedImpl(){
                    this.builder = new KReferenceBuilder(this);
            }
    
    public N and(){
            return (N) DestinationFluentImpl.this.withRef(builder.build());
    }
    public N endRef(){
            return and();
    }

}


}
